from setuptools import setup

setup(name='jnobless_dsnd_distributions',
      version='0.1',
      description='Gaussian, Binomial distributions',
      packages=['distributions'],
      author = 'June Ho Choi',
      author_email = 'mylegna0308@gmail.com',
      zip_safe=False)
